"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.attachDirectiveResolvers = void 0;
/*!
 * Copyright (c) Microsoft. All rights reserved.
 * Licensed under the MIT license. See LICENSE file in the project.
 */

/* eslint-disable @typescript-eslint/no-explicit-any */

const utils_1 = require("@graphql-tools/utils");

const graphql_1 = require("graphql");

function attachDirectiveResolvers(schema, directiveResolvers) {
  return (0, utils_1.mapSchema)(schema, {
    [utils_1.MapperKind.OBJECT_FIELD]: fieldConfig => {
      const newFieldConfig = _objectSpread({}, fieldConfig);

      const directives = (0, utils_1.getDirectives)(schema, fieldConfig);

      for (const directive of directives) {
        const directiveName = directive.name;

        if (directiveResolvers[directiveName]) {
          const resolver = directiveResolvers[directiveName];
          const originalResolver = newFieldConfig.resolve != null ? newFieldConfig.resolve : graphql_1.defaultFieldResolver;
          const directiveArgs = directive.args;

          newFieldConfig.resolve = (source, originalArgs, context, info) => {
            return resolver(() => new Promise((resolve, reject) => {
              const result = originalResolver(source, originalArgs, context, info);

              if (result instanceof Error) {
                reject(result);
              }

              resolve(result);
            }), source, directiveArgs, context, info);
          };
        }
      }

      return newFieldConfig;
    }
  });
}

exports.attachDirectiveResolvers = attachDirectiveResolvers;