import { FastifyInstance, FastifyRequest } from 'fastify';
import { GraphQLSchema } from 'graphql';
import { Logger } from 'pino';
import { IBaseConfiguration } from '../configuration';
import { IBuiltAppContext, IRequestAppContext } from '.';
export declare type PreRunCb = (app: FastifyInstance) => Promise<void>;
export interface RequestContextProvider<Configuration extends IBaseConfiguration, Components, RequestContext> {
    apply(ctx: IRequestAppContext<Configuration, Components, RequestContext>, request: FastifyRequest): Promise<Partial<RequestContext>>;
}
export declare class AppBuilder<Configuration extends IBaseConfiguration, Components, Context extends IBuiltAppContext<Configuration, Components>, RequestContext> {
    private _appContext;
    private _logger;
    private _schema;
    private _requestContextProviders;
    private _apolloServer;
    constructor(_appContext: Context, _logger: Logger, _schema: GraphQLSchema, _requestContextProviders: Array<RequestContextProvider<Configuration, Components, RequestContext>>);
    private get config();
    private createApolloServer;
    start(preRun?: PreRunCb): Promise<void>;
}
